API docs for “spamfighter.core.commands.test.test_serialize.RegisterTestCase”

# Class s.c.c.t.t.RegisterTestCase(unittest.TestCase):

Part of spamfighter.core.commands.test.test_serialize View Source View In Hierarchy

Тесты на `spamfighter.core.commands.serialize.register_serializer`, `spamfighter.core.commands.serialize.get_serializer`.

Method | test_get_serializer | Undocumented
Method | test_get_absent_serializer | Undocumented

def test_get_serializer(self): (source)
Undocumented
def test_get_absent_serializer(self): (source)
Undocumented